@@ -24,6 +24,9 @@ RedditModel::RedditModel(QObject *parent) :
 
     connect(m_ses, SIGNAL(commentsJsonAvailable(QString)), this,
             SIGNAL(commentsJsonAvailable(QString)));
+
+    connect(m_ses, SIGNAL(categoriesUpdated()), this, SLOT(refreshCategories()));
+
     QHash<int, QByteArray> roleNames;
     roleNames[RedditEntry::UrlRole] =  "url";
     roleNames[RedditEntry::DescRole] = "desc";
@@ -60,6 +63,8 @@ void RedditModel::setup(QDeclarativeContext *ctx)
     ctx->setContextProperty("mdlLinks", m_linksmodel);
     //ctx->setContextProperty("mdlComments", m_commentsmodel);
     ctx->setContextProperty("mdlCategories", m_cats);
+    ctx->setContextProperty("mdlRedditSession", m_ses);
+
     start("");
 
 }
@@ -85,6 +90,7 @@ void RedditModel::doPopulateLinks()
         it->setData(e.url, RedditEntry::UrlRole);
         it->setData(e.thumbnail, RedditEntry::ThumbnailRole);
         it->setData(e.comments, RedditEntry::CommentsRole);
+        it->setData(e.name, RedditEntry::NameRole);
 
         m_linksmodel->appendRow(it);
 
@@ -137,6 +143,8 @@ void RedditModel::refreshCategories()
         cats << "nsfw" << "gonewild" << "adult" << "sex";
     }
 
+    cats.removeDuplicates();
+
     m_cats->clear();
     foreach (QString c, cats) {
         QStandardItem* it = new QStandardItem();
